#!/bin/sh
# 
# 2008      Nico Schottelius (nico-cconf at schottelius.org)
# 
# This file is part of cconf.
#
# cconf is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# cconf is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with cconf. If not, see <http://www.gnu.org/licenses/>.
#
# Main script
#

hier="$(pwd -P)"        # where to search for cconf
dir="${hier}/cconf"     # the main configuration directory
exec="${dir}/libexec"   # contains executables used by cconf
tmpdir="${dir}/tmp"     # directory for temporary files
progdir="programs"      # subdir for program checks
searchfor="searchfor"   # which subdir contains things to search for

version="0.0.1"
version_name="Let the game begin"
author="Nico Schottelius"
fullversion="cconf ${version} (${version_name}) written by ${author}"

################################################################################
echo "${fullversion}"
echo ""

echo -n "Preparing tmp ... "
mkdir -p "${tmpdir}"             || exit 1
mkdir -p "${tmpdir}/${progdir}"  || exit 1
echo "ok"

echo "Detecting needed programs ..."

cd "${dir}/${searchfor}/${progdir}"
for prog in *; do
   echo -n "Checking for ${prog} ... "
   if [ -x "${exec}/${progdir}/${prog}" ]; then
      tmp="$("${exec}/${progdir}/${prog}")"
   else
      tmp="$(which "${prog}")"
   fi
   ret=$?

   if [ "$ret" -ne 0 ]; then
      echo "missing"
      exit 1
   else
      eval ${prog}=\"${tmp}\"
      eval echo "\$${prog}"
      file="${tmpdir}/${progdir}/${prog}"

      cat << eof > "${file}"
#!/bin/sh
#
# Autogenerated by ${fullversion}
# Created at $(date +%Y-%m-%d-%H:%M:%S)
#

eof
      eval echo "\$${prog} \\\"\\\$@\\\"" >> "${file}"
      chmod 0700 "${file}"
   fi
done
